@@ -36,7 +36,7 @@ def main():
             post='80'
         else:
             post=args.post
-        Version='1.3.1'
+        Version='1.4.5'
         console = Console()
         table = Table(title="[red]M x P i[/red]",style="bold")
         table.add_column("Version:"+Version, style="cyan", no_wrap=True,justify="center")
@@ -46,7 +46,7 @@ def main():
         table.add_row("")
         table.add_row("MxPi启动成功,打开:http://"+ip+':'+post,style="bold #0cd45c")
         table.add_row("")
-        table.add_row("教程文档地址:https://9421ndlpgb.k.topthink.com/@mxpi",style="bold")
+        table.add_row("教程地址:https://www.yuque.com/mxpi/doc",style="bold")
         try:
             ret = requests.get(pypiurl,timeout=2)
             if ret.status_code==200:
