@@ -676,7 +676,7 @@ function add(txt) {
 function add_com(txt) {
   list_num = list_num+1
   list_nums = list_nums+1
-  if(list_num>300){
+  if(list_num>3000){
   clears()
   list_num=0
   list_nums=0
@@ -1565,7 +1565,7 @@ function hsv2rgb_h(h,s,v)
 function pip_list(){
   $("#pip-table").tabulator({columns:[
     {title:"名称", field:"name", sortable:true,align:'center',sorter:"string", width:'20%'},
-    {title:"简介", field:"col", sorter:"string", sortable:false, width:'50%'},
+    {title:"简介", field:"col", sorter:"string", sortable:false, width:'48%'},
     {title:"系统", field:"arr", sorter:"string",align:'center',sortable:false, width:'20%'},
     {title:"操作", field:"cheese", sortable:true,align:'center',width:'10%'},
     ],
@@ -1584,6 +1584,8 @@ function pip_list(){
     {id:9, name:"hcsr04sensor",  col:"超声波传感器的依赖库", arr:'rpi',cheese:re('hcsr04sensor')},
     {id:10, name:"pyqtgraph",  col:"PyQt5可视化库", arr:'win/Liunx/rpi',cheese:re('pyqtgraph')},
     {id:11, name:"onnxruntime",  col:"目标检测的依赖库", arr:'win/Liunx/rpi',cheese:re('onnxruntime')},
+    {id:12, name:"mxpit",  col:"轻松训练目标检测与图像分类模型", arr:'win',cheese:re('mxpit')},
+    {id:13, name:"Sound_cls",  col:"音频分类依赖库", arr:'win/Liunx/rpi',cheese:re('Sound_cls')},
   ]);
 }
 
