@@ -436,7 +436,7 @@ Blockly.Blocks['method_procedures_defnoreturn'] = {
         option.text = Blockly.Msg.VARIABLES_SET_CREATE_GET.replace('%1', name);
         var xmlField = Blockly.utils.xml.createElement('field', null, name);
         xmlField.setAttribute('name', 'VAR');
-        xmlField.setAttribute('type', 'TYPEVAR');//新增
+        //xmlField.setAttribute('type', 'TYPEVAR');//新增
         var xmlBlock = Blockly.utils.xml.createElement('block', null, xmlField);
         xmlBlock.setAttribute('type', 'variables_get');
         option.callback = Blockly.ContextMenu.callbackFactory(this, xmlBlock);
