@@ -1108,3 +1108,356 @@ Blockly.Blocks.pyqt5_timer_start= {
   this.setHelpUrl("");
   }
 };
+
+Blockly.Blocks['procedures_callnoreturnsu'] = {
+  /**
+   * Block for calling a procedure with no return value.
+   * @this {Blockly.Block}
+   */
+  init: function() {
+    this.appendDummyInput('TOPROW')
+        .appendField('', 'NAME');
+    this.setOutput(true, null);
+    this.setStyle('procedure_blocks');
+    // Tooltip is set in renameProcedure.
+    this.setHelpUrl(Blockly.Msg['PROCEDURES_CALLNORETURN_HELPURL']);
+    this.arguments_ = [];
+    this.argumentVarModels_ = [];
+    this.quarkConnections_ = {};
+    this.quarkIds_ = null;
+    this.previousEnabledState_ = true;
+  },
+   
+ /**
+  * Returns the name of the procedure this block calls.
+  * @return {string} Procedure name.
+  * @this {Blockly.Block}
+  */
+ getProcedureCall: function() {
+  // The NAME field is guaranteed to exist, null will never be returned.
+  return /** @type {string} */ (this.getFieldValue('NAME'));
+},
+/**
+ * Notification that a procedure is renaming.
+ * If the name matches this block's procedure, rename it.
+ * @param {string} oldName Previous name of procedure.
+ * @param {string} newName Renamed procedure.
+ * @this {Blockly.Block}
+ */
+renameProcedure: function(oldName, newName) {
+  if (Blockly.Names.equals(oldName, this.getProcedureCall())) {
+    this.setFieldValue(newName, 'NAME');
+    var baseMsg = this.outputConnection ?
+        Blockly.Msg['PROCEDURES_CALLRETURN_TOOLTIP'] :
+        Blockly.Msg['PROCEDURES_CALLNORETURN_TOOLTIP'];
+    this.setTooltip(baseMsg.replace('%1', newName));
+  }
+},
+/**
+ * Notification that the procedure's parameters have changed.
+ * @param {!Array<string>} paramNames New param names, e.g. ['x', 'y', 'z'].
+ * @param {!Array<string>} paramIds IDs of params (consistent for each
+ *     parameter through the life of a mutator, regardless of param renaming),
+ *     e.g. ['piua', 'f8b_', 'oi.o'].
+ * @private
+ * @this {Blockly.Block}
+ */
+setProcedureParameters_: function(paramNames, paramIds) {
+  // Data structures:
+  // this.arguments = ['x', 'y']
+  //     Existing param names.
+  // this.quarkConnections_ {piua: null, f8b_: Blockly.Connection}
+  //     Look-up of paramIds to connections plugged into the call block.
+  // this.quarkIds_ = ['piua', 'f8b_']
+  //     Existing param IDs.
+  // Note that quarkConnections_ may include IDs that no longer exist, but
+  // which might reappear if a param is reattached in the mutator.
+  var defBlock = Blockly.Procedures.getDefinition(this.getProcedureCall(),
+      this.workspace);
+  var mutatorOpen = defBlock && defBlock.mutator &&
+      defBlock.mutator.isVisible();
+  if (!mutatorOpen) {
+    this.quarkConnections_ = {};
+    this.quarkIds_ = null;
+  }
+  if (!paramIds) {
+    // Reset the quarks (a mutator is about to open).
+    return;
+  }
+  // Test arguments (arrays of strings) for changes. '\n' is not a valid
+  // argument name character, so it is a valid delimiter here.
+  if (paramNames.join('\n') == this.arguments_.join('\n')) {
+    // No change.
+    this.quarkIds_ = paramIds;
+    return;
+  }
+  if (paramIds.length != paramNames.length) {
+    throw RangeError('paramNames and paramIds must be the same length.');
+  }
+  this.setCollapsed(false);
+  if (!this.quarkIds_) {
+    // Initialize tracking for this block.
+    this.quarkConnections_ = {};
+    this.quarkIds_ = [];
+  }
+  // Switch off rendering while the block is rebuilt.
+  var savedRendered = this.rendered;
+  this.rendered = false;
+  // Update the quarkConnections_ with existing connections.
+  for (var i = 0; i < this.arguments_.length; i++) {
+    var input = this.getInput('ARG' + i);
+    if (input) {
+      var connection = input.connection.targetConnection;
+      this.quarkConnections_[this.quarkIds_[i]] = connection;
+      if (mutatorOpen && connection &&
+          paramIds.indexOf(this.quarkIds_[i]) == -1) {
+        // This connection should no longer be attached to this block.
+        connection.disconnect();
+        connection.getSourceBlock().bumpNeighbours();
+      }
+    }
+  }
+  // Rebuild the block's arguments.
+  this.arguments_ = [].concat(paramNames);
+  // And rebuild the argument model list.
+  this.argumentVarModels_ = [];
+  for (var i = 0; i < this.arguments_.length; i++) {
+    var variable = Blockly.Variables.getOrCreateVariablePackage(
+        this.workspace, null, this.arguments_[i], '');
+    this.argumentVarModels_.push(variable);
+  }
+
+  this.updateShape_();
+  this.quarkIds_ = paramIds;
+  // Reconnect any child blocks.
+  if (this.quarkIds_) {
+    for (var i = 0; i < this.arguments_.length; i++) {
+      var quarkId = this.quarkIds_[i];
+      if (quarkId in this.quarkConnections_) {
+        var connection = this.quarkConnections_[quarkId];
+        if (!Blockly.Mutator.reconnect(connection, this, 'ARG' + i)) {
+          // Block no longer exists or has been attached elsewhere.
+          delete this.quarkConnections_[quarkId];
+        }
+      }
+    }
+  }
+  // Restore rendering and show the changes.
+  this.rendered = savedRendered;
+  if (this.rendered) {
+    this.render();
+  }
+},
+/**
+ * Modify this block to have the correct number of arguments.
+ * @private
+ * @this {Blockly.Block}
+ */
+updateShape_: function() {
+  for (var i = 0; i < this.arguments_.length; i++) {
+    var field = this.getField('ARGNAME' + i);
+    if (field) {
+      // Ensure argument name is up to date.
+      // The argument name field is deterministic based on the mutation,
+      // no need to fire a change event.
+      Blockly.Events.disable();
+      try {
+        field.setValue(this.arguments_[i]);
+      } finally {
+        Blockly.Events.enable();
+      }
+    } else {
+      // Add new input.
+      field = new Blockly.FieldLabel(this.arguments_[i]);
+      var input = this.appendValueInput('ARG' + i)
+          .setAlign(Blockly.ALIGN_RIGHT)
+          .appendField(field, 'ARGNAME' + i);
+      input.init();
+    }
+  }
+  // Remove deleted inputs.
+  while (this.getInput('ARG' + i)) {
+    this.removeInput('ARG' + i);
+    i++;
+  }
+  // Add 'with:' if there are parameters, remove otherwise.
+  var topRow = this.getInput('TOPROW');
+  if (topRow) {
+    if (this.arguments_.length) {
+      if (!this.getField('WITH')) {
+        topRow.appendField(Blockly.Msg['PROCEDURES_CALL_BEFORE_PARAMS'], 'WITH');
+        topRow.init();
+      }
+    } else {
+      if (this.getField('WITH')) {
+        topRow.removeField('WITH');
+      }
+    }
+  }
+},
+/**
+ * Create XML to represent the (non-editable) name and arguments.
+ * @return {!Element} XML storage element.
+ * @this {Blockly.Block}
+ */
+mutationToDom: function() {
+  var container = Blockly.utils.xml.createElement('mutation');
+  container.setAttribute('name', this.getProcedureCall());
+  for (var i = 0; i < this.arguments_.length; i++) {
+    var parameter = Blockly.utils.xml.createElement('arg');
+    parameter.setAttribute('name', this.arguments_[i]);
+    container.appendChild(parameter);
+  }
+  return container;
+},
+/**
+ * Parse XML to restore the (non-editable) name and parameters.
+ * @param {!Element} xmlElement XML storage element.
+ * @this {Blockly.Block}
+ */
+domToMutation: function(xmlElement) {
+  var name = xmlElement.getAttribute('name');
+  this.renameProcedure(this.getProcedureCall(), name);
+  var args = [];
+  var paramIds = [];
+  for (var i = 0, childNode; (childNode = xmlElement.childNodes[i]); i++) {
+    if (childNode.nodeName.toLowerCase() == 'arg') {
+      args.push(childNode.getAttribute('name'));
+      paramIds.push(childNode.getAttribute('paramId'));
+    }
+  }
+  this.setProcedureParameters_(args, paramIds);
+},
+/**
+ * Return all variables referenced by this block.
+ * @return {!Array<string>} List of variable names.
+ * @this {Blockly.Block}
+ */
+getVars: function() {
+  return this.arguments_;
+},
+/**
+ * Return all variables referenced by this block.
+ * @return {!Array<!Blockly.VariableModel>} List of variable models.
+ * @this {Blockly.Block}
+ */
+getVarModels: function() {
+  return this.argumentVarModels_;
+},
+/**
+ * Procedure calls cannot exist without the corresponding procedure
+ * definition.  Enforce this link whenever an event is fired.
+ * @param {!Blockly.Events.Abstract} event Change event.
+ * @this {Blockly.Block}
+ */
+onchange: function(event) {
+  if (!this.workspace || this.workspace.isFlyout) {
+    // Block is deleted or is in a flyout.
+    return;
+  }
+  if (!event.recordUndo) {
+    // Events not generated by user. Skip handling.
+    return;
+  }
+},
+/**
+ * Add menu option to find the definition block for this call.
+ * @param {!Array} options List of menu options to add to.
+ * @this {Blockly.Block}
+ */
+customContextMenu: function(options) {
+  if (!this.workspace.isMovable()) {
+    // If we center on the block and the workspace isn't movable we could
+    // loose blocks at the edges of the workspace.
+    return;
+  }
+
+  var option = {enabled: true};
+  option.text = Blockly.Msg['PROCEDURES_HIGHLIGHT_DEF'];
+  var name = this.getProcedureCall();
+  var workspace = this.workspace;
+  option.callback = function() {
+    var def = Blockly.Procedures.getDefinition(name, workspace);
+    if (def) {
+      workspace.centerOnBlock(def.id);
+      def.select();
+    }
+  };
+  options.push(option);
+},
+defType_: 'procedures_defnoreturnsu'
+};
+
+Blockly.Blocks.pyqt5_showFullScreen= {
+  init: function() {
+  this.appendDummyInput()
+      .appendField("设置窗口全屏显示");
+  this.setInputsInline(true);
+  this.setPreviousStatement(true, null);
+  this.setNextStatement(true, null);
+  this.setStyle('GUI_blocks');
+  this.setTooltip("在所有组件画完后使用全屏");
+  this.setHelpUrl("");
+  }
+};
+
+Blockly.Blocks.pyqt5_pyqtgraph_init= {
+  init: function() {
+  this.appendValueInput("NAME")
+      .setCheck(null)
+      .appendField("折线图");
+  this.appendValueInput("W")
+      .setCheck(null)
+      .appendField("宽");
+  this.appendValueInput("H")
+      .setCheck(null)
+      .appendField("高");
+  this.appendValueInput("X")
+      .setCheck(null)
+      .appendField("位置X");
+  this.appendValueInput("Y")
+      .setCheck(null)
+      .appendField("Y");
+  this.appendDummyInput()
+      .appendField("背景色")
+      .appendField(new Blockly.FieldColour("#ffffff"), "BG")
+      .appendField("前景色")
+      .appendField(new Blockly.FieldColour("#000099"), "FG")
+      .appendField("线条颜色")
+      .appendField(new Blockly.FieldColour("#ff0000"), "LG");
+  this.appendDummyInput()
+      .appendField("可拖动")
+      .appendField(new Blockly.FieldDropdown([["是","True"],["否","False"]]), "PAN");
+  this.setInputsInline(true);
+  this.setPreviousStatement(true, null);
+  this.setNextStatement(true, null);
+  this.setStyle('GUI_blocks');
+  this.setTooltip("创建折线图");
+  this.setHelpUrl("");
+  }
+};
+
+Blockly.Blocks.pyqt5_pyqtgraph_updata= {
+  init: function() {
+  this.appendValueInput("NAME")
+      .setCheck(null)
+      .appendField("折线图");
+  this.appendValueInput("NUM")
+      .setCheck(null)
+      .appendField("上传数据");
+  this.appendDummyInput()
+      .appendField("数据滞留")
+      .appendField(new Blockly.FieldDropdown([["是","True"],["否","False"]]), "BOOL");
+  this.appendValueInput("N")
+      .setCheck(null)
+      .appendField("保留数据");
+  this.appendDummyInput()
+      .appendField("个");
+  this.setInputsInline(true);
+  this.setPreviousStatement(true, null);
+  this.setNextStatement(true, null);
+  this.setStyle('GUI_blocks');
+  this.setTooltip("创建折线图");
+  this.setHelpUrl("");
+  }
+};
\ No newline at end of file
